@@ -1,13 +1,11 @@
 /*****************************************************************************
- *  $Id: path.c 771 2010-03-02 23:14:07Z dun $
- *****************************************************************************
  *  Written by Chris Dunlap <cdunlap@llnl.gov>.
- *  Copyright (C) 2007-2010 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2016 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2002-2007 The Regents of the University of California.
  *  UCRL-CODE-155910.
  *
  *  This file is part of the MUNGE Uid 'N' Gid Emporium (MUNGE).
- *  For details, see <http://home.gna.org/munge/>.
+ *  For details, see <https://dun.github.io/munge/>.
  *
  *  MUNGE is free software: you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
@@ -139,7 +137,7 @@ path_is_accessible (const char *path, char *errbuf, size_t errbuflen)
     }
     if (lstat (buf, &st) < 0) {
         return (_path_set_err (-1, errbuf, errbuflen,
-            "cannot check \"%s\": %s", buf, strerror (errno)));
+            "cannot stat \"%s\": %s", buf, strerror (errno)));
     }
     if (!S_ISDIR (st.st_mode)) {
         if ((p = strrchr (buf, '/'))) {
@@ -149,7 +147,7 @@ path_is_accessible (const char *path, char *errbuf, size_t errbuflen)
     while (buf[0] != '\0') {
         if (lstat (buf, &st) < 0) {
             return (_path_set_err (-1, errbuf, errbuflen,
-                "cannot check \"%s\": %s", buf, strerror (errno)));
+                "cannot stat \"%s\": %s", buf, strerror (errno)));
         }
         if (!S_ISDIR (st.st_mode)) {
             errno = EINVAL;
@@ -176,14 +174,14 @@ path_is_accessible (const char *path, char *errbuf, size_t errbuflen)
 
 
 int
-path_is_secure (const char *path, char *errbuf, size_t errbuflen)
+path_is_secure (const char *path, char *errbuf, size_t errbuflen,
+                path_security_flag_t flags)
 {
     int          n;
     char         buf [PATH_MAX];
     struct stat  st;
     char        *p;
     uid_t        euid;
-    gid_t        egid;
 
     n = path_canonicalize (path, buf, sizeof (buf));
     if (n < 0) {
@@ -197,7 +195,7 @@ path_is_secure (const char *path, char *errbuf, size_t errbuflen)
     }
     if (lstat (buf, &st) < 0) {
         return (_path_set_err (-1, errbuf, errbuflen,
-            "cannot check \"%s\": %s", buf, strerror (errno)));
+            "cannot stat \"%s\": %s", buf, strerror (errno)));
     }
     if (!S_ISDIR (st.st_mode)) {
         if ((p = strrchr (buf, '/'))) {
@@ -205,12 +203,11 @@ path_is_secure (const char *path, char *errbuf, size_t errbuflen)
         }
     }
     euid = geteuid ();
-    egid = getegid ();
 
     while (buf[0] != '\0') {
         if (lstat (buf, &st) < 0) {
             return (_path_set_err (-1, errbuf, errbuflen,
-                "cannot check \"%s\": %s", buf, strerror (errno)));
+                "cannot stat \"%s\": %s", buf, strerror (errno)));
         }
         if (!S_ISDIR (st.st_mode)) {
             errno = EINVAL;
@@ -221,7 +218,10 @@ path_is_secure (const char *path, char *errbuf, size_t errbuflen)
             return (_path_set_err (0, errbuf, errbuflen,
                 "invalid ownership of \"%s\"", buf));
         }
-        if ((st.st_mode & S_IWGRP) && !(st.st_mode & S_ISVTX)) {
+        if (!(flags & PATH_SECURITY_IGNORE_GROUP_WRITE) &&
+             (st.st_mode & S_IWGRP)                     &&
+            !(st.st_mode & S_ISVTX))
+        {
             return (_path_set_err (0, errbuf, errbuflen,
                 "group-writable permissions set on \"%s\"", buf));
         }
